@@ -23,12 +23,13 @@ po <- pomp(
                   dnorm(
                         x=x2['n'],
                         mean=n+r*n*(1-n/K)*delta.t,
-                        sd=sigma*n*sqrt(delta.t)
+                        sd=sigma*n*sqrt(delta.t),
+                        log=log
                         )
                   )
            },
            measurement.model=obs~lnorm(meanlog=log(n),sdlog=log(1+tau)),
-           skeleton=function(x,t,params,...){
+           skeleton.vectorfield=function(x,t,params,...){
              with(
                   as.list(c(x,params)),
                   r*n*(1-n/K)
@@ -40,4 +41,6 @@ po <- pomp(
 params <- c(n.0=10000,K=10000,r=0.9,sigma=0.4,tau=0.1)
 set.seed(73658676)
 po <- simulate(po,params=params)[[1]]
-plot(po)
+
+params <- cbind(c(n.0=100,K=10000,r=0.2,sigma=0.4,tau=0.1),c(n.0=1000,K=11000,r=0.1,sigma=0.4,tau=0.1))
+x <- trajectory(po,params=params)
