@@ -12,18 +12,26 @@ SEXP do_rprocess (SEXP object, SEXP xstart, SEXP times, SEXP params)
   SEXP X, fn, fcall, rho;
   SEXP dimXstart, dimP, dimX;
   ntimes = length(times);
-  if (ntimes < 2)
+  if (ntimes < 2) {
+    UNPROTECT(nprotect);
     error("rprocess error: no transitions, no work to do");
+  }
   PROTECT(dimXstart = GET_DIM(xstart)); nprotect++;
-  if ((isNull(dimXstart)) || (length(dimXstart)!=2))
+  if ((isNull(dimXstart)) || (length(dimXstart)!=2)) {
+    UNPROTECT(nprotect);
     error("rprocess error: 'xstart' must be a rank-2 array");
+  }
   PROTECT(dimP = GET_DIM(params)); nprotect++;
-  if ((isNull(dimP)) || (length(dimP)!=2))
+  if ((isNull(dimP)) || (length(dimP)!=2)) {
+    UNPROTECT(nprotect);
     error("rprocess error: 'params' must be a rank-2 array");
+  }
   xdim = INTEGER(dimXstart);
   nvars = xdim[0]; nreps = xdim[1];
-  if (nreps != INTEGER(dimP)[1])
+  if (nreps != INTEGER(dimP)[1]) {
+    UNPROTECT(nprotect);
     error("rprocess error: number of columns of 'params' and 'xstart' do not agree");
+  }
   // extract the process function
   PROTECT(fn = GET_SLOT(object,install("rprocess"))); nprotect++;
   // construct the call
@@ -50,13 +58,19 @@ SEXP do_rprocess (SEXP object, SEXP xstart, SEXP times, SEXP params)
   PROTECT(rho = (CLOENV(fn))); nprotect++; // environment of the function
   PROTECT(X = eval(fcall,rho)); nprotect++; // do the call
   PROTECT(dimX = GET_DIM(X)); nprotect++;
-  if ((isNull(dimX)) || (length(dimX) != 3))
+  if ((isNull(dimX)) || (length(dimX) != 3)) {
+    UNPROTECT(nprotect);
     error("rprocess error: user 'rprocess' must return a rank-3 array");
+  }
   xdim = INTEGER(dimX);
-  if ((xdim[0] != nvars) || (xdim[1] != nreps) || (xdim[2] != ntimes))
+  if ((xdim[0] != nvars) || (xdim[1] != nreps) || (xdim[2] != ntimes)) {
+    UNPROTECT(nprotect);
     error("rprocess error: user 'rprocess' must return a %d x %d x %d array",nvars,nreps,ntimes);
-  if (isNull(GET_ROWNAMES(GET_DIMNAMES(X))))
+  }
+  if (isNull(GET_ROWNAMES(GET_DIMNAMES(X)))) {
+    UNPROTECT(nprotect);
     error("rprocess error: user 'rprocess' must return an array with rownames");
+  }
   UNPROTECT(nprotect);
   return X;
 }
